==> core-1.0.2-20161026.090526-26-sources.jar: com/imcode/imcms/addon/imagearchive/util/Pagination.java <==
package com.imcode.imcms.addon.imagearchive.util;

import javax.servlet.http.HttpSession;
import java.io.Serializable;

public class Pagination implements Serializable{
    private static final long serialVersionUID = -7220000190165261133L;
    public static final int DEFAULT_PAGE_SIZE = 20;

    private int pageSize = 1;
    private int startPosition;
    private int currentPage;
    private int pageCount;
    private boolean hasNextPage;
    private boolean hasPrevPage;
    
    
    public Pagination() {
    }
    
    public Pagination(int pageSize) {
        this.pageSize = pageSize;
    }
    
    
    public static Pagination create(int pageSize, int currentPage, int elementCount) {
        Pagination pagination = new Pagination(pageSize);
        
        pagination.setCurrentPage(currentPage);
        pagination.update(elementCount);
        
        return pagination;
    }

    public static Pagination getPagination(HttpSession session, String paginationKey) {
        return getPagination(session, paginationKey, DEFAULT_PAGE_SIZE);
    }

    public static Pagination getPagination(HttpSession session, String paginationKey, int defaultPageSize) {
        Pagination pag = (Pagination) session.getAttribute(paginationKey);
        if (pag == null) {
            pag = new Pagination(defaultPageSize);
            session.setAttribute(paginationKey, pag);
        }

        return pag;
    }
    
    public void update(int elementCount) {
        pageCount = ((elementCount - 1) / pageSize) + 1;
        
        currentPage = Math.min(currentPage, pageCount - 1);
        currentPage = Math.max(currentPage, 0);
        
        startPosition = currentPage * pageSize;
        
        startPosition = Math.min(startPosition, elementCount - 1);
        startPosition = Math.max(startPosition, 0);
        
        hasNextPage = (currentPage < (pageCount - 1));
        hasPrevPage = (currentPage > 0);
    }

    public int getCurrentPage() {
        return currentPage;
    }

    public void setCurrentPage(int currentPage) {
        this.currentPage = currentPage;
    }

    public int getPageSize() {
        return pageSize;
    }

    public void setPageSize(int pageSize) {
        this.pageSize = pageSize;
    }

    public int getStartPosition() {
        return startPosition;
    }

    public boolean isHasNextPage() {
        return hasNextPage;
    }

    public boolean isHasPrevPage() {
        return hasPrevPage;
    }

    public int getPageCount() {
        return pageCount;
    }
}

==> core-1.0.3-20171212.151920-19-sources.jar: com/imcode/imcms/addon/imagearchive/util/Pagination.java <==
package com.imcode.imcms.addon.imagearchive.util;

import javax.servlet.http.HttpSession;
import java.io.Serializable;

public class Pagination implements Serializable{
    private static final long serialVersionUID = -7220000190165261133L;
    public static final int DEFAULT_PAGE_SIZE = 20;

    private int pageSize = 1;
    private int startPosition;
    private int currentPage;
    private int pageCount;
    private int allElementsCount;
    private boolean hasNextPage;
    private boolean hasPrevPage;
    
    
    public Pagination() {
    }
    
    public Pagination(int pageSize) {
        this.pageSize = pageSize;
    }
    
    
    public static Pagination create(int pageSize, int currentPage, int elementCount) {
        Pagination pagination = new Pagination(pageSize);
        
        pagination.setCurrentPage(currentPage);
        pagination.update(elementCount);
        
        return pagination;
    }

    public static Pagination getPagination(HttpSession session, String paginationKey) {
        return getPagination(session, paginationKey, DEFAULT_PAGE_SIZE);
    }

    public static Pagination getPagination(HttpSession session, String paginationKey, int defaultPageSize) {
        Pagination pag = (Pagination) session.getAttribute(paginationKey);
        if (pag == null) {
            pag = new Pagination(defaultPageSize);
            session.setAttribute(paginationKey, pag);
        }

        return pag;
    }
    
    public void update(int elementCount) {
        this.allElementsCount = elementCount;
        pageCount = ((elementCount - 1) / pageSize) + 1;
        
        currentPage = Math.min(currentPage, pageCount - 1);
        currentPage = Math.max(currentPage, 0);
        
        startPosition = currentPage * pageSize;
        
        startPosition = Math.min(startPosition, elementCount - 1);
        startPosition = Math.max(startPosition, 0);
        
        hasNextPage = (currentPage < (pageCount - 1));
        hasPrevPage = (currentPage > 0);
    }

    public int getCurrentPage() {
        return currentPage;
    }

    public void setCurrentPage(int currentPage) {
        this.currentPage = currentPage;
    }

    public int getPageSize() {
        return pageSize;
    }

    public void setPageSize(int pageSize) {
        this.pageSize = pageSize;
    }

    public int getStartPosition() {
        return startPosition;
    }

    public boolean isHasNextPage() {
        return hasNextPage;
    }

    public boolean isHasPrevPage() {
        return hasPrevPage;
    }

    public int getPageCount() {
        return pageCount;
    }

    public int getAllElementsCount() {
        return allElementsCount;
    }
}
